@@ -23,7 +23,6 @@ if(!isGeneric("decode")) {
                function(x, ...) standardGeneric("decode"))
 }
 
-
 if(!isGeneric("hyperlift")) {
     setGeneric("hyperlift",
                function(x, ...) standardGeneric("hyperlift"))
@@ -43,11 +42,6 @@ if(!isGeneric("itemInfo<-")) {
                function(object, value) standardGeneric("itemInfo<-"))
 }
 
-if(!isGeneric("labels")) {
-    setGeneric("labels",
-               function(object, ...) standardGeneric("labels"))
-}
-
 if(!isGeneric("itemLabels")) {
     setGeneric("itemLabels",
                function(object, ...) standardGeneric("itemLabels"))
@@ -68,6 +62,21 @@ if(!isGeneric("items<-")) {
                function(x, value) standardGeneric("items<-"))
 }
 
+if(!isGeneric("itemSupport")) {
+    setGeneric("itemSupport",
+               function(x, ...) standardGeneric("itemSupport"))
+}
+
+if(!isGeneric("itemFrequencyPlot")) {
+    setGeneric("itemFrequencyPlot",
+               function(x, ...) standardGeneric("itemFrequencyPlot"))
+}
+
+if(!isGeneric("labels")) {
+    setGeneric("labels",
+               function(object, ...) standardGeneric("labels"))
+}
+
 if(!isGeneric("lhs")) {
     setGeneric("lhs",
                function(x) standardGeneric("lhs"))
@@ -98,16 +107,16 @@ if(!isGeneric("rhs<-")) {
                function(x, value) standardGeneric("rhs<-"))
 }
 
+if(!isGeneric("ruleInduction")) {
+    setGeneric("ruleInduction",
+               function(x, ...) standardGeneric("ruleInduction"))
+}
+
 if(!isGeneric("size")) {
     setGeneric("size",
                function(x) standardGeneric("size"))
 }
 
-if(!isGeneric("itemSupport")) {
-    setGeneric("itemSupport",
-               function(x, ...) standardGeneric("itemSupport"))
-}
-
 if(!isGeneric("subset")) {
     setGeneric("subset",
                function(x, ...) standardGeneric("subset"))
